==> streamtuner-0.12.4.tar.gz: streamtuner-0.12.4/src/streamtuner/st-general-tab.c <==
/*
 * $Id: st-general-tab.c,v 1.27.2.3 2004/07/25 18:39:37 jylefort Exp $
 *
 * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include <gtk/gtk.h>
#include "art/general_preferences.h"
#include "gettext.h"
#include "sgtk-hig.h"
#include "st-general-tab.h"
#include "st-preferences.h"
#include "st-settings.h"
#include "st-preferences-tab.h"

/*** type definitions ********************************************************/

struct _STGeneralTabPrivate
{
  GtkTooltips	*tooltips;
};
  
/*** variable declarations ***************************************************/

static GObjectClass *parent_class = NULL;

/*** function declarations ***************************************************/

static void st_general_tab_class_init (STGeneralTabClass *class);
static void st_general_tab_init (STGeneralTab *tab);
static void st_general_tab_finalize (GObject *object);

/*** implementation **********************************************************/

GType
st_general_tab_get_type (void)
{
  static GType general_tab_type = 0;
  
  if (! general_tab_type)
    {
      static const GTypeInfo general_tab_info = {
	sizeof(STGeneralTabClass),
	NULL,
	NULL,
	(GClassInitFunc) st_general_tab_class_init,
	NULL,
	NULL,
	sizeof(STGeneralTab),
	0,
	(GInstanceInitFunc) st_general_tab_init,
      };

      general_tab_type = g_type_register_static(ST_TYPE_PREFERENCES_TAB,
						"STGeneralTab",
						&general_tab_info,
						0);
    }

  return general_tab_type;
}

static void
st_general_tab_class_init (STGeneralTabClass *class)
{
  GObjectClass *object_class = G_OBJECT_CLASS(class);
  STPreferencesTabClass *preferences_tab_class = ST_PREFERENCES_TAB_CLASS(class);

  parent_class = g_type_class_peek_parent(class);
  
  object_class->finalize = st_general_tab_finalize;

  preferences_tab_class->link_id = "preferences-general";
}

static void
st_general_tab_init (STGeneralTab *tab)
{
  GdkPixbuf *pixbuf;
  GtkWidget *table;
  GtkWidget *splash_enabled;
  GtkWidget *always_refresh;
  GtkWidget *save_automatic;

  tab->priv = g_new0(STGeneralTabPrivate, 1);
  tab->priv->tooltips = gtk_tooltips_new();

  pixbuf = gdk_pixbuf_new_from_inline(sizeof(art_general_preferences),
				      art_general_preferences,
				      FALSE,
				      NULL);

  st_preferences_tab_construct_label(ST_PREFERENCES_TAB(tab), pixbuf, _("General"));
  g_object_unref(pixbuf);

  gtk_container_set_border_width(GTK_CONTAINER(tab), SGTK_HIG_CONTROLS_BORDER_WIDTH);

  splash_enabled = gtk_check_button_new_with_mnemonic(_("Sh_ow splash screen at startup"));
  gtk_tooltips_set_tip(tab->priv->tooltips, splash_enabled,
		       _("If this option is enabled, a splash screen will be shown when starting streamtuner."),
		       NULL);

  always_refresh = gtk_check_button_new_with_mnemonic(_("_Always refresh categories"));
  gtk_tooltips_set_tip(tab->priv->tooltips, always_refresh,
		       _("If this option is enabled, categories will always be refreshed when you select them."),
		       NULL);

  save_automatic = gtk_check_button_new_with_mnemonic(_("_Save session upon exit"));
  gtk_tooltips_set_tip(tab->priv->tooltips, save_automatic,
		       _("If this option is enabled, your session will be saved upon exit.\n"
			 "Otherwise, you will be asked what to do."),
		       NULL);

  st_preferences_bind_boolean(GTK_TOGGLE_BUTTON(splash_enabled), &st_settings.splash_enabled);
  st_preferences_bind_boolean(GTK_TOGGLE_BUTTON(always_refresh), &st_settings.always_refresh);
  st_preferences_bind_boolean(GTK_TOGGLE_BUTTON(save_automatic), &st_settings.save_automatic);
 
  table = gtk_table_new(3, 1, FALSE);

  gtk_table_set_row_spacings(GTK_TABLE(table), SGTK_HIG_CONTROL_SPACING);
  gtk_table_set_col_spacings(GTK_TABLE(table), SGTK_HIG_CONTROL_SPACING);

  gtk_table_attach(GTK_TABLE(table), splash_enabled, 0, 1, 0, 1,
		   GTK_EXPAND | GTK_FILL,
		   0,
		   0,
		   0);
  gtk_table_attach(GTK_TABLE(table), always_refresh, 0, 1, 1, 2,
		   GTK_EXPAND | GTK_FILL,
		   0,
		   0,
		   0);
  gtk_table_attach(GTK_TABLE(table), save_automatic, 0, 1, 2, 3,
		   GTK_EXPAND | GTK_FILL,
		   0,
		   0,
		   0);

  gtk_widget_show_all(table);
  gtk_container_add(GTK_CONTAINER(tab), table);
}

static void
st_general_tab_finalize (GObject *object)
{
  STGeneralTab *tab = ST_GENERAL_TAB(object);

  gtk_object_destroy(GTK_OBJECT(tab->priv->tooltips));
  g_free(tab->priv);

  G_OBJECT_CLASS(parent_class)->finalize(object);
}

GtkWidget *
st_general_tab_new (void)
{
  return g_object_new(ST_TYPE_GENERAL_TAB, NULL);
}

==> streamtuner-0.12.5.tar.gz: streamtuner-0.12.5/src/streamtuner/st-general-tab.c <==
/*
 * $Id: st-general-tab.c,v 1.27.2.4 2004/08/06 00:36:30 jylefort Exp $
 *
 * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include <gtk/gtk.h>
#include "art/general_preferences.h"
#include "gettext.h"
#include "sgtk-hig.h"
#include "st-general-tab.h"
#include "st-preferences.h"
#include "st-settings.h"
#include "st-preferences-tab.h"

/*** type definitions ********************************************************/

struct _STGeneralTabPrivate
{
  GtkTooltips	*tooltips;
};
  
/*** variable declarations ***************************************************/

static GObjectClass *parent_class = NULL;

/*** function declarations ***************************************************/

static void st_general_tab_class_init (STGeneralTabClass *class);
static void st_general_tab_init (STGeneralTab *tab);
static void st_general_tab_finalize (GObject *object);

/*** implementation **********************************************************/

GType
st_general_tab_get_type (void)
{
  static GType general_tab_type = 0;
  
  if (! general_tab_type)
    {
      static const GTypeInfo general_tab_info = {
	sizeof(STGeneralTabClass),
	NULL,
	NULL,
	(GClassInitFunc) st_general_tab_class_init,
	NULL,
	NULL,
	sizeof(STGeneralTab),
	0,
	(GInstanceInitFunc) st_general_tab_init,
      };

      general_tab_type = g_type_register_static(ST_TYPE_PREFERENCES_TAB,
						"STGeneralTab",
						&general_tab_info,
						0);
    }

  return general_tab_type;
}

static void
st_general_tab_class_init (STGeneralTabClass *class)
{
  GObjectClass *object_class = G_OBJECT_CLASS(class);
  STPreferencesTabClass *preferences_tab_class = ST_PREFERENCES_TAB_CLASS(class);

  parent_class = g_type_class_peek_parent(class);
  
  object_class->finalize = st_general_tab_finalize;

  preferences_tab_class->link_id = "preferences-general";
}

static void
st_general_tab_init (STGeneralTab *tab)
{
  GdkPixbuf *pixbuf;
  GtkWidget *table;
  GtkWidget *splash_enabled;
  GtkWidget *always_reload;
  GtkWidget *save_automatic;

  tab->priv = g_new0(STGeneralTabPrivate, 1);
  tab->priv->tooltips = gtk_tooltips_new();

  pixbuf = gdk_pixbuf_new_from_inline(sizeof(art_general_preferences),
				      art_general_preferences,
				      FALSE,
				      NULL);

  st_preferences_tab_construct_label(ST_PREFERENCES_TAB(tab), pixbuf, _("General"));
  g_object_unref(pixbuf);

  gtk_container_set_border_width(GTK_CONTAINER(tab), SGTK_HIG_CONTROLS_BORDER_WIDTH);

  splash_enabled = gtk_check_button_new_with_mnemonic(_("Sh_ow splash screen at startup"));
  gtk_tooltips_set_tip(tab->priv->tooltips, splash_enabled,
		       _("If this option is enabled, a splash screen will be shown when starting streamtuner."),
		       NULL);

  always_reload = gtk_check_button_new_with_mnemonic(_("_Always reload categories"));
  gtk_tooltips_set_tip(tab->priv->tooltips, always_reload,
		       _("If this option is enabled, categories will always be reloaded when you select them."),
		       NULL);

  save_automatic = gtk_check_button_new_with_mnemonic(_("_Save session upon exit"));
  gtk_tooltips_set_tip(tab->priv->tooltips, save_automatic,
		       _("If this option is enabled, your session will be saved upon exit.\n"
			 "Otherwise, you will be asked what to do."),
		       NULL);

  st_preferences_bind_boolean(GTK_TOGGLE_BUTTON(splash_enabled), &st_settings.splash_enabled);
  st_preferences_bind_boolean(GTK_TOGGLE_BUTTON(always_reload), &st_settings.always_reload);
  st_preferences_bind_boolean(GTK_TOGGLE_BUTTON(save_automatic), &st_settings.save_automatic);
 
  table = gtk_table_new(3, 1, FALSE);

  gtk_table_set_row_spacings(GTK_TABLE(table), SGTK_HIG_CONTROL_SPACING);
  gtk_table_set_col_spacings(GTK_TABLE(table), SGTK_HIG_CONTROL_SPACING);

  gtk_table_attach(GTK_TABLE(table), splash_enabled, 0, 1, 0, 1,
		   GTK_EXPAND | GTK_FILL,
		   0,
		   0,
		   0);
  gtk_table_attach(GTK_TABLE(table), always_reload, 0, 1, 1, 2,
		   GTK_EXPAND | GTK_FILL,
		   0,
		   0,
		   0);
  gtk_table_attach(GTK_TABLE(table), save_automatic, 0, 1, 2, 3,
		   GTK_EXPAND | GTK_FILL,
		   0,
		   0,
		   0);

  gtk_widget_show_all(table);
  gtk_container_add(GTK_CONTAINER(tab), table);
}

static void
st_general_tab_finalize (GObject *object)
{
  STGeneralTab *tab = ST_GENERAL_TAB(object);

  gtk_object_destroy(GTK_OBJECT(tab->priv->tooltips));
  g_free(tab->priv);

  G_OBJECT_CLASS(parent_class)->finalize(object);
}

GtkWidget *
st_general_tab_new (void)
{
  return g_object_new(ST_TYPE_GENERAL_TAB, NULL);
}
